==> paykunpay-lib-1.1.1-sources.jar: paykunpay/yashoka/com/paykunpay_lib/PaykunPaymentActivity.java <==
package paykunpay.yashoka.com.paykunpay_lib;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.net.http.SslError;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.webkit.SslErrorHandler;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.VolleyLog;
import com.android.volley.toolbox.JsonObjectRequest;

import org.json.JSONException;
import org.json.JSONObject;

import static paykunpay.yashoka.com.paykunpay_lib.AppController.TAG;

public class PaykunPaymentActivity extends AppCompatActivity {

    private ProgressDialog pDialog;
    WebView webView;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        //initializeOptions();
        setContentView(R.layout.activity_paykun_payment);
        webView = (WebView)findViewById(R.id.webview);
        //Toast.makeText(this," this is activity ",Toast.LENGTH_SHORT).show();
        makeJsonObjectRequest(this);
    }
    private void makeJsonObjectRequest(final Activity activity) {
        Constant.showProgressDialog(this);
        JSONObject object = new JSONObject();
        try {
            object.put("merchant_id","201805020001");
            object.put("access_token","asdjfjsdaklfsajf");
            object.put("customer_name","Prashant");
            object.put("customer_email","kambadprashant@gmail.com");
            object.put("customer_phone","9974740564");
            object.put("product_name","Yasoka Product");
            object.put("order_no","789581254");
            object.put("amount","20");
            object.put("device_id","device_id");
            object.put("imei_no","1235644897645");

            object.put("package_name","com.tesdc.test");
            object.put("device_token","aasdfjlkasdfjalksrioewrjlkdsjflsdajf");
            object.put("client_ip","127.0.0.1");
            object.put("os_name","android");
            object.put("os_version","8");

            object.put("timestamp","1552545854");
            object.put("signature","alksdjflasdjflkjasjhasjkasdgfkjashkhjsadhfjsdjfnjsjerhiuisufwrieigbakbbbakjghsdkfhjsddfkasdjffbaskjdfbfdsk");
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JsonObjectRequest jsonObjReq = new JsonObjectRequest(Request.Method.POST,
                Constant.urlJsonObj, object, new Response.Listener<JSONObject>() {

            @Override
            public void onResponse(JSONObject response) {
                Log.e(" response : ", response.toString());
                String token ;
                String orderUrl = "";
                try {
                    token = response.getString("_token");
                    orderUrl = response.getString("order_url");

                } catch (JSONException e) {
                    e.printStackTrace();
                }
                webView.getSettings().setJavaScriptEnabled(true);
                webView.setWebViewClient(new WebViewClient(){
                    @Override
                    public boolean shouldOverrideUrlLoading(WebView view, String url) {
                        //progDailog.show();
                        //view.loadUrl(url);
                        return true;
                    }
                    @Override
                    public void onPageFinished(WebView view, final String url) {
                        //progDailog.dismiss();
                    }
                    @Override
                    public void onReceivedSslError(WebView view, SslErrorHandler handler, SslError error) {
                        handler.proceed();
                    }
                });
                webView.loadUrl(orderUrl);
                Constant.hideProgressDialog();
            }
        }, new Response.ErrorListener() {

            @Override
            public void onErrorResponse(VolleyError error) {
                VolleyLog.d(TAG, "Error: " + error.getMessage());
                Toast.makeText(activity, error.getMessage(), Toast.LENGTH_SHORT).show();
                // hide the progress dialog
                Constant.hideProgressDialog();
            }
        });
        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(jsonObjReq);
    }
}

==> paykunpay-lib-1.1.2-sources.jar: paykunpay/yashoka/com/paykunpay_lib/PaykunPaymentActivity.java <==
package paykunpay.yashoka.com.paykunpay_lib;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.net.http.SslError;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.webkit.CookieManager;
import android.webkit.SslErrorHandler;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.VolleyLog;
import com.android.volley.toolbox.JsonObjectRequest;

import org.json.JSONException;
import org.json.JSONObject;

import static paykunpay.yashoka.com.paykunpay_lib.AppController.TAG;

public class PaykunPaymentActivity extends AppCompatActivity {

    private ProgressDialog pDialog;
    WebView webView;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        //initializeOptions();
        setContentView(R.layout.activity_paykun_payment);
        webView = (WebView)findViewById(R.id.webview);
        //Toast.makeText(this," this is activity ",Toast.LENGTH_SHORT).show();
        makeJsonObjectRequest(this);
        // new comment
    }
    private void makeJsonObjectRequest(final Activity activity) {
        Constant.showProgressDialog(this);
        JSONObject object = new JSONObject();
        try {
            object.put("merchant_id","201805020001");
            object.put("access_token","asdjfjsdaklfsajf");
            object.put("customer_name","Prashant");
            object.put("customer_email","kambadprashant@gmail.com");
            object.put("customer_phone","9974740564");
            object.put("product_name","Yasoka Product");
            object.put("order_no","789581254");
            object.put("amount","20");
            object.put("device_id","device_id");
            object.put("imei_no","1235644897645");

            object.put("package_name","com.tesdc.test");
            object.put("device_token","aasdfjlkasdfjalksrioewrjlkdsjflsdajf");
            object.put("client_ip","127.0.0.1");
            object.put("os_name","android");
            object.put("os_version","8");

            object.put("timestamp","1552545854");
            object.put("signature","alksdjflasdjflkjasjhasjkasdgfkjashkhjsadhfjsdjfnjsjerhiuisufwrieigbakbbbakjghsdkfhjsddfkasdjffbaskjdfbfdsk");
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JsonObjectRequest jsonObjReq = new JsonObjectRequest(Request.Method.POST,
                Constant.urlJsonObj, object, new Response.Listener<JSONObject>() {

            @Override
            public void onResponse(JSONObject response) {
                Log.e(" response : ", response.toString());
                String token = "";
                String orderUrl = "";
                try {
                    token = response.getString("_token");
                    orderUrl = response.getString("order_url");

                } catch (JSONException e) {
                    e.printStackTrace();
                }
                //webView = new WebView(activity);
                webView.getSettings().setJavaScriptEnabled(true);
                webView.getSettings().setDomStorageEnabled(true);

                String cookieString = "_token="+token;
                CookieManager.getInstance().setCookie(orderUrl, cookieString);


                webView.setWebViewClient(new WebViewClient(){
                    @Override
                    public boolean shouldOverrideUrlLoading(WebView view, String url) {
                        //progDailog.show();
                        //view.loadUrl(url);
                        return true;
                    }
                    @Override
                    public void onPageFinished(WebView view, final String url) {
                        //progDailog.dismiss();
                    }
                    @Override
                    public void onReceivedSslError(WebView view, SslErrorHandler handler, SslError error) {
                        handler.proceed();
                    }
                });
                webView.loadUrl(orderUrl);
                Constant.hideProgressDialog();
            }
        }, new Response.ErrorListener() {

            @Override
            public void onErrorResponse(VolleyError error) {
                VolleyLog.d(TAG, "Error: " + error.getMessage());
                Toast.makeText(activity, error.getMessage(), Toast.LENGTH_SHORT).show();
                // hide the progress dialog
                Constant.hideProgressDialog();
            }
        });
        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(jsonObjReq);
    }
}
